@@ -9,7 +9,7 @@ use crate::traits::Show;
 
 use super::*;
 
-impl Show for Node {
+impl Show for corev1::Node {
     fn show(&self) -> String {
         let condition = self
             .status
@@ -36,7 +36,7 @@ impl Show for Node {
     }
 }
 
-impl Show for Pod {
+impl Show for corev1::Pod {
     fn show(&self) -> String {
         let status = self
             .status
@@ -57,7 +57,7 @@ impl Show for Pod {
     }
 }
 
-impl Show for Namespace {
+impl Show for corev1::Namespace {
     fn show(&self) -> String {
         format!("Namespace: {}", self.name())
     }
