@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -280,19 +280,24 @@ impl StateHub {
             .install_statehub_cluster(namespace)
             .await
             .with_event(event);
-        self.report_event(event).await?;
+        let statehub_cluster = self.report_event(event).await?;
 
-        self.setup_cluster_token_helper(&kubectl, &cluster, register_cluster)
+        self.setup_cluster_token_helper(&kubectl, &cluster, &statehub_cluster)
             .await?;
         self.setup_credentials_helper(
             &kubectl,
-            &register_cluster.namespace,
+            &statehub_cluster,
             &register_cluster.aws,
             &register_cluster.azure,
         )
         .await?;
-        self.setup_configmap_helper(&kubectl, &cluster, register_cluster)
-            .await?;
+        self.setup_configmap_helper(
+            &kubectl,
+            &statehub_cluster,
+            register_cluster.default_state.as_deref().unwrap_or(""),
+            &register_cluster.cleanup_grace,
+        )
+        .await?;
 
         if register_cluster.claim_unowned_states {
             self.claim_unowned_states_helper(&cluster, register_cluster)
@@ -564,21 +569,18 @@ or run following commands before running 'statehub register-cluster`
     pub(super) async fn setup_configmap_helper(
         &self,
         kubectl: &k8s::Kubectl,
-        cluster: &v0::Cluster,
-        register_cluster: &RegisterCluster,
+        statehub_cluster: &StatehubCluster,
+        default_state: &str,
+        cleanup_grace: &str,
+        // register_cluster: &RegisterCluster,
     ) -> anyhow::Result<()> {
-        let default_state = register_cluster.default_state.as_deref().unwrap_or("");
+        let operator = kubectl.get_operator().await?;
+        let namespace = statehub_cluster.namespace();
         let api = self.api.url("");
 
-        let event = self.setup_configmap_event(&register_cluster.namespace);
-        let event = kubectl
-            .store_configmap(
-                &register_cluster.namespace,
-                &cluster.name,
-                default_state,
-                &api,
-                &register_cluster.cleanup_grace,
-            )
+        let event = self.setup_configmap_event(namespace);
+        let event = operator
+            .create_configmap(statehub_cluster, default_state, &api, cleanup_grace)
             .await
             .with_event(event);
         self.report_event(event).await?;
@@ -590,14 +592,15 @@ or run following commands before running 'statehub register-cluster`
         &self,
         kubectl: &k8s::Kubectl,
         cluster: &v0::Cluster,
-        register_cluster: &RegisterCluster,
+        statehub_cluster: &StatehubCluster,
     ) -> anyhow::Result<()> {
         let token = self.api.issue_cluster_token(&cluster.name).await?;
         self.verbosely(format!("Issued token {} for {}", token.token, cluster))?;
+        let operator = kubectl.get_operator().await?;
 
-        let event = self.store_cluster_token_event(&register_cluster.namespace);
-        let event = kubectl
-            .store_cluster_token(&register_cluster.namespace, &token.token)
+        let event = self.store_cluster_token_event(statehub_cluster.namespace());
+        let event = operator
+            .create_cluster_token_secret(statehub_cluster, &token.token)
             .await
             .with_event(event);
         self.report_event(event).await?;
@@ -608,15 +611,20 @@ or run following commands before running 'statehub register-cluster`
     pub(super) async fn setup_credentials_helper(
         &self,
         kubectl: &k8s::Kubectl,
-        namespace: &str,
+        statehub_cluster: &StatehubCluster,
         aws: &AwsCredentials,
         azure: &AzureCredentials,
     ) -> anyhow::Result<()> {
         let aws = json::to_value(aws)?;
-        let _secret = kubectl.store_aws_credentials(namespace, aws).await?;
-
         let azure = json::to_value(azure)?;
-        let _secret = kubectl.store_azure_credentials(namespace, azure).await?;
+        let operator = kubectl.get_operator().await?;
+
+        operator
+            .create_aws_credentials_secret(statehub_cluster, aws)
+            .await?;
+        operator
+            .create_azure_credentials_secret(statehub_cluster, azure)
+            .await?;
 
         Ok(())
     }
